@@ -1,9 +1,10 @@
 # 获取没有填写备注的人的名字并去重
 import pandas as pd
+import dataito
 
-def qunat(flie_path,write_path,name_idx,qianzhui='',info_idx=''):
-    
-    df = pd.read_csv(flie_path, header=0)
+def qunat(flie_path,write_path,name_idx,qianzhui='',info_idx='',header=0):
+
+    df = dataito.read(flie_path,header)
     if info_idx == '':
         info_idx = df.shape[1]    #备注所在列数（默认最后一列）
 
@@ -16,6 +17,6 @@ def qunat(flie_path,write_path,name_idx,qianzhui='',info_idx=''):
 
     name = pd.DataFrame(name)
     name = pd.DataFrame(name.iloc[:,0].unique())    #去重
-
+  
     name.to_csv(write_path,index=None,header=None)
     print(name)
\ No newline at end of file
